@@ -3,8 +3,7 @@ import os
 from pathlib import Path
 
 import orjson
-from typing import Callable, Tuple, Any, Dict, Optional, Union, TypeVar
-
+from typing import Callable, MutableMapping, Tuple, Any, Dict, Optional, Union, TypeVar
 
 F = TypeVar("F", bound=Callable)
 
@@ -14,6 +13,10 @@ class CacheMethod:
     def single_object_arg(args, _kwargs):
         return id(args[0])
 
+    @staticmethod
+    def single_literal_arg(args, _kwargs):
+        return args[0]
+
     @staticmethod
     def two_object_args(args, _kwargs):
         return (id(args[0]), id(args[1]))
@@ -28,7 +31,8 @@ class CacheMethod:
 
     @staticmethod
     def cache(
-        key: Callable[[tuple, dict], Union[tuple, str, bytes, int]]
+        key: Callable[[tuple, dict], Union[tuple, str, bytes, int]],
+        cache_attr: str = "_cache",
     ) -> Callable[[F], F]:
         """Cache instance's method during its life-time.
         Note: Order of the arguments is important. Different order of the arguments will result in different cache key.
@@ -39,12 +43,13 @@ class CacheMethod:
 
             @functools.wraps(func)
             def fn(self, *args, **kwargs):
-                if not hasattr(self, "_cache"):
-                    self._cache = {}
+                if not hasattr(self, cache_attr):
+                    setattr(self, cache_attr, {})
+                cache = getattr(self, cache_attr)
                 k = (fn_name, key(args, kwargs))
-                if k not in self._cache:
-                    self._cache[k] = func(self, *args, **kwargs)
-                return self._cache[k]
+                if k not in cache:
+                    cache[k] = func(self, *args, **kwargs)
+                return cache[k]
 
             return fn
 
@@ -80,3 +85,23 @@ def exec_or_skip_if_file_exist(filepath: Union[Path, str], skip: bool = False):
             fn()
 
     return wrapper_fn
+
+
+def cache_fn(
+    cache: MutableMapping[bytes, Any],
+    key: Optional[Callable[[str, tuple, dict], bytes]] = None,
+) -> Callable[[F], F]:
+    def wrapper_fn(func):
+        fn_name = func.__name__
+
+        @functools.wraps(func)
+        def fn(self, *args, **kwargs):
+
+            k = orjson.dumps((fn_name, args, kwargs))
+            if k not in cache:
+                cache[k] = func(self, *args, **kwargs)
+            return cache[k]
+
+        return fn
+
+    return wrapper_fn  # type: ignore
